@@ -2,6 +2,6 @@ from .objects import PhotoObj, SpecObj
 from .regions import Region
 from .refs import manga_ancillary
 from .utils import (decode_objid, decode_specid, sql2df, sql_columns, binimg2array,
-                    img_cutout, show_spect, show_object, download_frame)
+                    img_cutout, show_spect, show_object)
 
-__version__ = "0.2.5"
+__version__ = "0.4.0"
